@@ -10,6 +10,7 @@ class FoursquareOAuth2(BaseOAuth2):
     AUTHORIZATION_URL = 'https://foursquare.com/oauth2/authenticate'
     ACCESS_TOKEN_URL = 'https://foursquare.com/oauth2/access_token'
     ACCESS_TOKEN_METHOD = 'POST'
+    API_VERSION = '20140128'
 
     def get_user_id(self, details, response):
         return response['response']['user']['id']
@@ -27,4 +28,5 @@ class FoursquareOAuth2(BaseOAuth2):
     def user_data(self, access_token, *args, **kwargs):
         """Loads user data from service"""
         return self.get_json('https://api.foursquare.com/v2/users/self',
-                             params={'oauth_token': access_token})
+                             params={'oauth_token': access_token,
+                                     'v': self.API_VERSION})
